From 30052530771205d052e9113e3ccb23d36349f8c3 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Ond=C5=99ej=20Sur=C3=BD?= <ondrej@sury.org>
Date: Thu, 12 May 2011 16:40:03 +0200
Subject: [PATCH] Add purge_dir command to dpkg-maintscript-helper

---
 scripts/dpkg-maintscript-helper.sh |   38 +++++++++++++++++++++++++++++++++++-
 1 files changed, 37 insertions(+), 1 deletions(-)

diff --git a/scripts/dpkg-maintscript-helper.sh b/scripts/dpkg-maintscript-helper.sh
index 631a5a1..91cd072 100755
--- a/scripts/dpkg-maintscript-helper.sh
+++ b/scripts/dpkg-maintscript-helper.sh
@@ -216,6 +216,39 @@ abort_mv_conffile() {
 	fi
 }
 
+purge_dir() {
+	local DIRECTORY="$1"
+	local PACKAGE="$2"
+	if [ "${PACKAGE}" = "--" -o -z "${PACKAGE}" ]; then
+		PACKAGE="${DPKG_MAINTSCRIPT_PACKAGE}"
+	fi
+
+	while [ "$DIRECTORY" != "/" ]; do
+
+		local OWNED_BY="$(dpkg-query -S "${DIRECTORY}" 2>/dev/null | cut -f 1 -d :)"
+
+		if [ -z "${OWNED_BY}" -o "${OWNED_BY}" = "${PACKAGE}" ]; then
+			[ -d "${DIRECTORY}" ] && \
+			    rmdir --ignore-fail-on-non-empty "${DIRECTORY}"
+
+			# Directory was not removed
+			if [ -d "${DIRECTORY}" ]; then
+				echo "Unable to remove ${DIRECTORY}: directory not empty"
+				return 1
+			else
+				DIRECTORY="$(dirname "${DIRECTORY}")"
+				purge_dir "${DIRECTORY}" "${PACKAGE}"
+				return $?
+			fi
+		else
+			debug "Preserving ${DIRECTORY}; still owned by ${#OWNED_BY} package(s)"
+			return 0
+		fi
+	done
+
+	return 0
+}
+
 # Common functions
 debug() {
 	if [ -n "$DPKG_DEBUG" ]; then
@@ -272,7 +305,7 @@ shift
 case "$command" in
 supports)
 	case "$1" in
-	rm_conffile|mv_conffile)
+	rm_conffile|mv_conffile|purge_dir)
 		code=0
 		;;
 	*)
@@ -295,6 +328,9 @@ rm_conffile)
 mv_conffile)
 	mv_conffile "$@"
 	;;
+purge_dir)
+	purge_dir "$@"
+	;;
 --help|help|-?|-h)
 	usage
 	;;
-- 
1.7.2.5

